Module accel

Module accel 

Structs

Accel
This is used to enable an accelerator. Depending on the target architecture, kvm, xen, hvf, nvmm, whpx or tcg can be available. By default, tcg is used. If there is more than one accelerator specified, the next one is used if the previous one fails to initialize.
AccelBuilder
Use builder syntax to set the inputs and finish with build().

Enums

NotifyVMExit
QEMU notify-vmexit= values.
OnOffSplit
QEMU kernel-irqchip= values for -accel.
TCGThreadType
QEMU thread= values for TCG acceleration.