Accel

Struct Accel 

pub struct Accel { /* private fields */ }
This is used to enable an accelerator. Depending on the target architecture, kvm, xen, hvf, nvmm, whpx or tcg can be available. By default, tcg is used. If there is more than one accelerator specified, the next one is used if the previous one fails to initialize.

Implementations

Source

impl Accel

pub fn builder() -> AccelBuilder

Create an instance of Accel using the builder syntax

Source

impl Accel

pub fn new(accel_type: AccelType) -> Self

Creates an accelerator configuration for the given backend.