AcpiTable

Struct AcpiTable 

pub struct AcpiTable { /* private fields */ }
Add ACPI table with specified header fields and context from specified files. For file=, take whole ACPI table from the specified files, including all ACPI headers (possible overridden by other options). For data=, only data portion of the table is used, all header information is specified in the command line. If a SLIC table is supplied to QEMU, then the SLIC’s oem_id and oem_table_id fields will override the same in the RSDT and the FADT (a.k.a. FACP), in order to ensure the field matches required by the Microsoft SLIC spec and the ACPI spec.

Implementations

Source

impl AcpiTable

pub fn builder() -> AcpiTableBuilder

Create an instance of AcpiTable using the builder syntax

Source

impl AcpiTable

pub fn new() -> Self

Creates an empty -acpitable argument builder for incremental setup.