pub struct AddFd {
pub fd: usize,
pub set: usize,
pub opaque: Option<ShellString>,
}Expand description
Add a file descriptor to a fd set.
Fields
fd: usizeThis option defines the file descriptor of which a duplicate is added to fd set. The file descriptor cannot be stdin, stdout, or stderr.
set: usizeThis option defines the ID of the fd set to add the file descriptor to.
opaque: Option<ShellString>This option defines a free-form string that can be used to describe fd.
Implementations