pub struct Device { /* private fields */ }Expand description
Add a QEMU device driver with optional prop or prop=value settings.
Valid properties depend on the device driver. Use -device help or
-device driver,help in QEMU for the device-specific property list.
Implementations
Sourceimpl Device
impl Device
Sourcepub fn builder() -> DeviceBuilder
pub fn builder() -> DeviceBuilder
Create an instance of Device using the builder syntax
Sourceimpl Device
impl Device
Sourcepub fn new<S: AsRef<str>>(device: S) -> Self
pub fn new<S: AsRef<str>>(device: S) -> Self
Creates a new device argument for the given QEMU device driver.
Sourcepub fn arm_smmuv3() -> Self
pub fn arm_smmuv3() -> Self
Creates the QEMU 11.1 ARM SMMUv3 device. Properties such as ril,
ats, oas, ssidsize, and cmdqv accept QEMU’s auto value via
Device::add_prop.
Sourcepub fn from_json(json: impl Into<String>) -> Result<Self, String>
pub fn from_json(json: impl Into<String>) -> Result<Self, String>
Creates a device from QEMU’s JSON command-line form.