Module fsdev

Module fsdev 

Structs

FsDevLocal
A -fsdev local,... backend.
FsDevLocalBuilder
Use builder syntax to set the inputs and finish with build().
FsDevSynth
A synthetic -fsdev synth,... backend used by QTests.
FsDevSynthBuilder
Use builder syntax to set the inputs and finish with build().

Enums

FsDev
Define a new QEMU file system device.
SecurityModel
QEMU security_model= values for -fsdev local.