FsDevLocalBuilder

Struct FsDevLocalBuilder 

pub struct FsDevLocalBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> FsDevLocalBuilder<S>

pub fn build(self) -> FsDevLocal
where S: IsComplete,

Finish building and return the requested object

pub fn id(self, value: String) -> FsDevLocalBuilder<SetId<S>>
where S::Id: IsUnset,

Required.

Specifies identifier for this device.

pub fn path(self, value: PathBuf) -> FsDevLocalBuilder<SetPath<S>>
where S::Path: IsUnset,

Required.

Specifies the export path for the file system device.

pub fn security_model( self, value: SecurityModel, ) -> FsDevLocalBuilder<SetSecurityModel<S>>
where S::SecurityModel: IsUnset,

Required.

Specifies the security model to be used for this export path.

pub fn writeout(self, value: ()) -> FsDevLocalBuilder<SetWriteout<S>>
where S::Writeout: IsUnset,

Optional (Some / Option setters). Emit writeout=immediate when enabled.

pub fn maybe_writeout( self, value: Option<()>, ) -> FsDevLocalBuilder<SetWriteout<S>>
where S::Writeout: IsUnset,

Optional (Some / Option setters). Emit writeout=immediate when enabled.

pub fn readonly(self, value: ()) -> FsDevLocalBuilder<SetReadonly<S>>
where S::Readonly: IsUnset,

Optional (Some / Option setters). Emit readonly=on when enabled.

pub fn maybe_readonly( self, value: Option<()>, ) -> FsDevLocalBuilder<SetReadonly<S>>
where S::Readonly: IsUnset,

Optional (Some / Option setters). Emit readonly=on when enabled.

pub fn fmode(self, value: String) -> FsDevLocalBuilder<SetFmode<S>>
where S::Fmode: IsUnset,

Optional (Some / Option setters). Specifies the default mode for newly created files on the host.

pub fn maybe_fmode( self, value: Option<String>, ) -> FsDevLocalBuilder<SetFmode<S>>
where S::Fmode: IsUnset,

Optional (Some / Option setters). Specifies the default mode for newly created files on the host.

pub fn dmode(self, value: String) -> FsDevLocalBuilder<SetDmode<S>>
where S::Dmode: IsUnset,

Optional (Some / Option setters). Specifies the default mode for newly created directories on the host.

pub fn maybe_dmode( self, value: Option<String>, ) -> FsDevLocalBuilder<SetDmode<S>>
where S::Dmode: IsUnset,

Optional (Some / Option setters). Specifies the default mode for newly created directories on the host.

pub fn throttling_bps_total( self, value: usize, ) -> FsDevLocalBuilder<SetThrottlingBpsTotal<S>>
where S::ThrottlingBpsTotal: IsUnset,

Optional (Some / Option setters). Throttling limits in bytes per second.

pub fn maybe_throttling_bps_total( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetThrottlingBpsTotal<S>>
where S::ThrottlingBpsTotal: IsUnset,

Optional (Some / Option setters). Throttling limits in bytes per second.

pub fn throttling_bps_read( self, value: usize, ) -> FsDevLocalBuilder<SetThrottlingBpsRead<S>>
where S::ThrottlingBpsRead: IsUnset,

Optional (Some / Option setters).

pub fn maybe_throttling_bps_read( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetThrottlingBpsRead<S>>
where S::ThrottlingBpsRead: IsUnset,

Optional (Some / Option setters).

pub fn throttling_bps_write( self, value: usize, ) -> FsDevLocalBuilder<SetThrottlingBpsWrite<S>>
where S::ThrottlingBpsWrite: IsUnset,

Optional (Some / Option setters).

pub fn maybe_throttling_bps_write( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetThrottlingBpsWrite<S>>
where S::ThrottlingBpsWrite: IsUnset,

Optional (Some / Option setters).

pub fn throttling_bps_total_max( self, value: usize, ) -> FsDevLocalBuilder<SetThrottlingBpsTotalMax<S>>
where S::ThrottlingBpsTotalMax: IsUnset,

Optional (Some / Option setters). Bursts in bytes per second.

pub fn maybe_throttling_bps_total_max( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetThrottlingBpsTotalMax<S>>
where S::ThrottlingBpsTotalMax: IsUnset,

Optional (Some / Option setters). Bursts in bytes per second.

pub fn bps_read_max(self, value: usize) -> FsDevLocalBuilder<SetBpsReadMax<S>>
where S::BpsReadMax: IsUnset,

Optional (Some / Option setters).

pub fn maybe_bps_read_max( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetBpsReadMax<S>>
where S::BpsReadMax: IsUnset,

Optional (Some / Option setters).

pub fn bps_write_max(self, value: usize) -> FsDevLocalBuilder<SetBpsWriteMax<S>>
where S::BpsWriteMax: IsUnset,

Optional (Some / Option setters).

pub fn maybe_bps_write_max( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetBpsWriteMax<S>>
where S::BpsWriteMax: IsUnset,

Optional (Some / Option setters).

pub fn throttling_iops_total( self, value: usize, ) -> FsDevLocalBuilder<SetThrottlingIopsTotal<S>>
where S::ThrottlingIopsTotal: IsUnset,

Optional (Some / Option setters). Request rate limits in requests per second.

pub fn maybe_throttling_iops_total( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetThrottlingIopsTotal<S>>
where S::ThrottlingIopsTotal: IsUnset,

Optional (Some / Option setters). Request rate limits in requests per second.

pub fn throttling_iops_read( self, value: usize, ) -> FsDevLocalBuilder<SetThrottlingIopsRead<S>>
where S::ThrottlingIopsRead: IsUnset,

Optional (Some / Option setters).

pub fn maybe_throttling_iops_read( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetThrottlingIopsRead<S>>
where S::ThrottlingIopsRead: IsUnset,

Optional (Some / Option setters).

pub fn throttling_iops_write( self, value: usize, ) -> FsDevLocalBuilder<SetThrottlingIopsWrite<S>>
where S::ThrottlingIopsWrite: IsUnset,

Optional (Some / Option setters).

pub fn maybe_throttling_iops_write( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetThrottlingIopsWrite<S>>
where S::ThrottlingIopsWrite: IsUnset,

Optional (Some / Option setters).

pub fn throttling_iops_total_max( self, value: usize, ) -> FsDevLocalBuilder<SetThrottlingIopsTotalMax<S>>
where S::ThrottlingIopsTotalMax: IsUnset,

Optional (Some / Option setters). Bursts in requests per second.

pub fn maybe_throttling_iops_total_max( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetThrottlingIopsTotalMax<S>>
where S::ThrottlingIopsTotalMax: IsUnset,

Optional (Some / Option setters). Bursts in requests per second.

pub fn throttling_iops_read_max( self, value: usize, ) -> FsDevLocalBuilder<SetThrottlingIopsReadMax<S>>
where S::ThrottlingIopsReadMax: IsUnset,

Optional (Some / Option setters).

pub fn maybe_throttling_iops_read_max( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetThrottlingIopsReadMax<S>>
where S::ThrottlingIopsReadMax: IsUnset,

Optional (Some / Option setters).

pub fn throttling_iops_write_max( self, value: usize, ) -> FsDevLocalBuilder<SetThrottlingIopsWriteMax<S>>
where S::ThrottlingIopsWriteMax: IsUnset,

Optional (Some / Option setters).

pub fn maybe_throttling_iops_write_max( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetThrottlingIopsWriteMax<S>>
where S::ThrottlingIopsWriteMax: IsUnset,

Optional (Some / Option setters).

pub fn throttling_iops_size( self, value: usize, ) -> FsDevLocalBuilder<SetThrottlingIopsSize<S>>
where S::ThrottlingIopsSize: IsUnset,

Optional (Some / Option setters). Request size for IOPS throttling accounting.

pub fn maybe_throttling_iops_size( self, value: Option<usize>, ) -> FsDevLocalBuilder<SetThrottlingIopsSize<S>>
where S::ThrottlingIopsSize: IsUnset,

Optional (Some / Option setters). Request size for IOPS throttling accounting.