Module machine

Module machine 

Structs

CxlFmw
A CXL fixed memory window definition for -machine.
CxlFmwBuilder
Use builder syntax to set the inputs and finish with build().
Machine
Select the emulated machine by name. Use -machine help to list available machines.
MachineAarch64
MachineAarch64Builder
Use builder syntax to set the inputs and finish with build().
MachineBuilder
Use builder syntax to set the inputs and finish with build().
MachineX86_64
MachineX86_64Builder
Use builder syntax to set the inputs and finish with build().
SgxEpc
An SGX EPC section definition for -machine sgx-epc.N.*.
SgxEpcBuilder
Use builder syntax to set the inputs and finish with build().
SmpCache
Cache topology properties for -machine smp-cache.*.
SmpCacheBuilder
Use builder syntax to set the inputs and finish with build().

Enums

Granularity
Supported interleave-granularity= values for cxl-fmw.
MachineType
Architecture-specific machine types accepted by this crate.