Memory

Struct Memory 

pub struct Memory { /* private fields */ }
Sets guest startup RAM size to megs megabytes. Default is 128 MiB. Optionally, a suffix of “M” or “G” can be used to signify a value in megabytes or gigabytes respectively. Optional pair slots, maxmem could be used to set amount of hotpluggable memory slots and maximum amount of memory. Note that maxmem must be aligned to the page size.

For example, the following command-line sets the guest startup RAM size to 1GB, creates 3 slots to hotplug additional memory and sets the maximum memory the guest can reach to 4GB:

-m 1G,slots=3,maxmem=4G

If slots and maxmem are not specified, memory hotplug won’t be enabled and the guest startup RAM will never increase.

Implementations

Source

impl Memory

pub fn builder() -> MemoryBuilder

Create an instance of Memory using the builder syntax