Module netdev

Module netdev 

Structs

AfXdp
AfXdpBuilder
Use builder syntax to set the inputs and finish with build().
Bridge
A -netdev bridge,... backend.
BridgeBuilder
Use builder syntax to set the inputs and finish with build().
DgramFd
DgramFdBuilder
Use builder syntax to set the inputs and finish with build().
DgramMulticast
DgramMulticastBuilder
Use builder syntax to set the inputs and finish with build().
DgramMulticastUdpFd
DgramMulticastUdpFdBuilder
Use builder syntax to set the inputs and finish with build().
DgramSocket
DgramSocketBuilder
Use builder syntax to set the inputs and finish with build().
DgramUds
DgramUdsBuilder
Use builder syntax to set the inputs and finish with build().
GuestForward
GuestForwardBuilder
Use builder syntax to set the inputs and finish with build().
HostAndMaybePort
A host and optional port used by listen= socket endpoints.
HostAndMaybePortBuilder
Use builder syntax to set the inputs and finish with build().
HostAndPort
A host and port pair used by socket-based -netdev backends.
HostAndPortBuilder
Use builder syntax to set the inputs and finish with build().
HostForward
HostForwardBuilder
Use builder syntax to set the inputs and finish with build().
Hubport
A -netdev hubport,... backend.
HubportBuilder
Use builder syntax to set the inputs and finish with build().
NetMap
NetMapBuilder
Use builder syntax to set the inputs and finish with build().
Passt
A -netdev passt,... backend.
PasstBuilder
Use builder syntax to set the inputs and finish with build().
SMB
A QEMU -netdev backend.
SMBBuilder
Use builder syntax to set the inputs and finish with build().
SocketMulticast
A -netdev socket,... multicast backend using mcast=.
SocketMulticastBuilder
Use builder syntax to set the inputs and finish with build().
SocketRegular
A -netdev socket,... backend using listen= and/or connect=.
SocketRegularBuilder
Use builder syntax to set the inputs and finish with build().
SocketUdpTunnel
A -netdev socket,... UDP tunnel backend using udp=.
SocketUdpTunnelBuilder
Use builder syntax to set the inputs and finish with build().
StreamOverFd
StreamOverFdBuilder
Use builder syntax to set the inputs and finish with build().
StreamOverTcp
StreamOverTcpBuilder
Use builder syntax to set the inputs and finish with build().
StreamOverUds
StreamOverUdsBuilder
Use builder syntax to set the inputs and finish with build().
Tap
TapBuilder
Use builder syntax to set the inputs and finish with build().
User
UserBuilder
Use builder syntax to set the inputs and finish with build().
Vde
VdeBuilder
Use builder syntax to set the inputs and finish with build().
VhostUser
A -netdev vhost-user,... backend.
VhostUserBuilder
Use builder syntax to set the inputs and finish with build().
VhostVdpa
A -netdev vhost-vdpa,... backend.
VhostVdpaBuilder
Use builder syntax to set the inputs and finish with build().
VmnetBridged
VmnetBridgedBuilder
Use builder syntax to set the inputs and finish with build().
VmnetHost
VmnetHostBuilder
Use builder syntax to set the inputs and finish with build().
VmnetShared
VmnetSharedBuilder
Use builder syntax to set the inputs and finish with build().

Enums

Dgram
GuestForwardTarget
NativeSkb
NetDev
ScriptOrNot
Socket
The socket backend variants supported by this crate.
Stream
TcpUdp