Module network_compat

Module network_compat 

Structs

LegacyNet
The compatibility -net interface retained by QEMU 11.1.
LegacyNetBuilder
Use builder syntax to set the inputs and finish with build().
NetworkProperty
An order-preserving property used by the broad -nic and legacy -net syntaxes.
Nic
QEMU’s shortcut for creating a host backend and an on-board NIC together.
NicBuilder
Use builder syntax to set the inputs and finish with build().