Module serial

Module serial 

Structs

Tcp
TcpBuilder
Use builder syntax to set the inputs and finish with build().
Telnet
TelnetBuilder
Use builder syntax to set the inputs and finish with build().
Udp
UdpBuilder
Use builder syntax to set the inputs and finish with build().
Unix
UnixBuilder
Use builder syntax to set the inputs and finish with build().
VC
A QEMU special character device target used by options such as -serial, -parallel, -monitor, and -qmp.
VCBuilder
Use builder syntax to set the inputs and finish with build().
Websocket
WebsocketBuilder
Use builder syntax to set the inputs and finish with build().

Enums

SpecialDevice