Module tpmdev

Module tpmdev 

Structs

Emulator
A -tpmdev emulator,... backend.
EmulatorBuilder
Use builder syntax to set the inputs and finish with build().
Passthrough
A -tpmdev passthrough,... backend.
PassthroughBuilder
Use builder syntax to set the inputs and finish with build().

Enums

TpmDev