pub struct Audio { /* private fields */ }Expand description
QEMU -audio [driver=]driver[,model=value][,prop[=value][,...]].
This shortcut configures a default host audio backend and optionally the
guest audio device model. Additional backend properties are emitted after
the canonical driver and model fields.
Implementations
Sourceimpl Audio
impl Audio
Sourcepub fn builder() -> AudioBuilder
pub fn builder() -> AudioBuilder
Create an instance of Audio using the builder syntax
Sourceimpl Audio
impl Audio
Sourcepub fn new(driver: impl Into<String>) -> Self
pub fn new(driver: impl Into<String>) -> Self
Creates an audio configuration for the given backend driver.
Sourcepub fn model(&mut self, model: impl Into<String>) -> &mut Self
pub fn model(&mut self, model: impl Into<String>) -> &mut Self
Sets the guest audio device model used by the -audio shortcut.