pub struct CharNull { /* private fields */ }Expand description
A QEMU -chardev backend.
The parser supports the canonical backend forms that this crate renders for
common QEMU character device backends such as socket, stdio, file,
pipe, pty, hub, and related simple backends.
Implementations