Structs
- FsDev
Local - A
-fsdev local,...backend. - FsDev
Local Builder - Use builder syntax to set the inputs and finish with
build(). - FsDev
Synth - A synthetic
-fsdev synth,...backend used by QTests. - FsDev
Synth Builder - Use builder syntax to set the inputs and finish with
build().
Enums
- FsDev
- Define a new QEMU file system device.
- Security
Model - QEMU
security_model=values for-fsdev local.