pub struct FsDevLocalBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> FsDevLocalBuilder<S>
impl<S: State> FsDevLocalBuilder<S>
Sourcepub fn build(self) -> FsDevLocalwhere
S: IsComplete,
pub fn build(self) -> FsDevLocalwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn id(self, value: String) -> FsDevLocalBuilder<SetId<S>>where
S::Id: IsUnset,
pub fn id(self, value: String) -> FsDevLocalBuilder<SetId<S>>where
S::Id: IsUnset,
Required.
Specifies identifier for this device.
Sourcepub fn path(self, value: PathBuf) -> FsDevLocalBuilder<SetPath<S>>where
S::Path: IsUnset,
pub fn path(self, value: PathBuf) -> FsDevLocalBuilder<SetPath<S>>where
S::Path: IsUnset,
Required.
Specifies the export path for the file system device.
Sourcepub fn security_model(
self,
value: SecurityModel,
) -> FsDevLocalBuilder<SetSecurityModel<S>>where
S::SecurityModel: IsUnset,
pub fn security_model(
self,
value: SecurityModel,
) -> FsDevLocalBuilder<SetSecurityModel<S>>where
S::SecurityModel: IsUnset,
Required.
Specifies the security model to be used for this export path.
Sourcepub fn writeout(self, value: ()) -> FsDevLocalBuilder<SetWriteout<S>>where
S::Writeout: IsUnset,
pub fn writeout(self, value: ()) -> FsDevLocalBuilder<SetWriteout<S>>where
S::Writeout: IsUnset,
Sourcepub fn maybe_writeout(
self,
value: Option<()>,
) -> FsDevLocalBuilder<SetWriteout<S>>where
S::Writeout: IsUnset,
pub fn maybe_writeout(
self,
value: Option<()>,
) -> FsDevLocalBuilder<SetWriteout<S>>where
S::Writeout: IsUnset,
Sourcepub fn readonly(self, value: ()) -> FsDevLocalBuilder<SetReadonly<S>>where
S::Readonly: IsUnset,
pub fn readonly(self, value: ()) -> FsDevLocalBuilder<SetReadonly<S>>where
S::Readonly: IsUnset,
Sourcepub fn maybe_readonly(
self,
value: Option<()>,
) -> FsDevLocalBuilder<SetReadonly<S>>where
S::Readonly: IsUnset,
pub fn maybe_readonly(
self,
value: Option<()>,
) -> FsDevLocalBuilder<SetReadonly<S>>where
S::Readonly: IsUnset,
Sourcepub fn fmode(self, value: String) -> FsDevLocalBuilder<SetFmode<S>>where
S::Fmode: IsUnset,
pub fn fmode(self, value: String) -> FsDevLocalBuilder<SetFmode<S>>where
S::Fmode: IsUnset,
Sourcepub fn maybe_fmode(
self,
value: Option<String>,
) -> FsDevLocalBuilder<SetFmode<S>>where
S::Fmode: IsUnset,
pub fn maybe_fmode(
self,
value: Option<String>,
) -> FsDevLocalBuilder<SetFmode<S>>where
S::Fmode: IsUnset,
Sourcepub fn dmode(self, value: String) -> FsDevLocalBuilder<SetDmode<S>>where
S::Dmode: IsUnset,
pub fn dmode(self, value: String) -> FsDevLocalBuilder<SetDmode<S>>where
S::Dmode: IsUnset,
Sourcepub fn maybe_dmode(
self,
value: Option<String>,
) -> FsDevLocalBuilder<SetDmode<S>>where
S::Dmode: IsUnset,
pub fn maybe_dmode(
self,
value: Option<String>,
) -> FsDevLocalBuilder<SetDmode<S>>where
S::Dmode: IsUnset,
Sourcepub fn throttling_bps_total(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingBpsTotal<S>>where
S::ThrottlingBpsTotal: IsUnset,
pub fn throttling_bps_total(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingBpsTotal<S>>where
S::ThrottlingBpsTotal: IsUnset,
Sourcepub fn maybe_throttling_bps_total(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingBpsTotal<S>>where
S::ThrottlingBpsTotal: IsUnset,
pub fn maybe_throttling_bps_total(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingBpsTotal<S>>where
S::ThrottlingBpsTotal: IsUnset,
Sourcepub fn throttling_bps_read(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingBpsRead<S>>where
S::ThrottlingBpsRead: IsUnset,
pub fn throttling_bps_read(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingBpsRead<S>>where
S::ThrottlingBpsRead: IsUnset,
Sourcepub fn maybe_throttling_bps_read(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingBpsRead<S>>where
S::ThrottlingBpsRead: IsUnset,
pub fn maybe_throttling_bps_read(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingBpsRead<S>>where
S::ThrottlingBpsRead: IsUnset,
Sourcepub fn throttling_bps_write(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingBpsWrite<S>>where
S::ThrottlingBpsWrite: IsUnset,
pub fn throttling_bps_write(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingBpsWrite<S>>where
S::ThrottlingBpsWrite: IsUnset,
Sourcepub fn maybe_throttling_bps_write(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingBpsWrite<S>>where
S::ThrottlingBpsWrite: IsUnset,
pub fn maybe_throttling_bps_write(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingBpsWrite<S>>where
S::ThrottlingBpsWrite: IsUnset,
Sourcepub fn throttling_bps_total_max(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingBpsTotalMax<S>>where
S::ThrottlingBpsTotalMax: IsUnset,
pub fn throttling_bps_total_max(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingBpsTotalMax<S>>where
S::ThrottlingBpsTotalMax: IsUnset,
Sourcepub fn maybe_throttling_bps_total_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingBpsTotalMax<S>>where
S::ThrottlingBpsTotalMax: IsUnset,
pub fn maybe_throttling_bps_total_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingBpsTotalMax<S>>where
S::ThrottlingBpsTotalMax: IsUnset,
Sourcepub fn bps_read_max(self, value: usize) -> FsDevLocalBuilder<SetBpsReadMax<S>>where
S::BpsReadMax: IsUnset,
pub fn bps_read_max(self, value: usize) -> FsDevLocalBuilder<SetBpsReadMax<S>>where
S::BpsReadMax: IsUnset,
Sourcepub fn maybe_bps_read_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetBpsReadMax<S>>where
S::BpsReadMax: IsUnset,
pub fn maybe_bps_read_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetBpsReadMax<S>>where
S::BpsReadMax: IsUnset,
Sourcepub fn bps_write_max(self, value: usize) -> FsDevLocalBuilder<SetBpsWriteMax<S>>where
S::BpsWriteMax: IsUnset,
pub fn bps_write_max(self, value: usize) -> FsDevLocalBuilder<SetBpsWriteMax<S>>where
S::BpsWriteMax: IsUnset,
Sourcepub fn maybe_bps_write_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetBpsWriteMax<S>>where
S::BpsWriteMax: IsUnset,
pub fn maybe_bps_write_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetBpsWriteMax<S>>where
S::BpsWriteMax: IsUnset,
Sourcepub fn throttling_iops_total(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsTotal<S>>where
S::ThrottlingIopsTotal: IsUnset,
pub fn throttling_iops_total(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsTotal<S>>where
S::ThrottlingIopsTotal: IsUnset,
Sourcepub fn maybe_throttling_iops_total(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsTotal<S>>where
S::ThrottlingIopsTotal: IsUnset,
pub fn maybe_throttling_iops_total(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsTotal<S>>where
S::ThrottlingIopsTotal: IsUnset,
Sourcepub fn throttling_iops_read(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsRead<S>>where
S::ThrottlingIopsRead: IsUnset,
pub fn throttling_iops_read(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsRead<S>>where
S::ThrottlingIopsRead: IsUnset,
Sourcepub fn maybe_throttling_iops_read(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsRead<S>>where
S::ThrottlingIopsRead: IsUnset,
pub fn maybe_throttling_iops_read(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsRead<S>>where
S::ThrottlingIopsRead: IsUnset,
Sourcepub fn throttling_iops_write(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsWrite<S>>where
S::ThrottlingIopsWrite: IsUnset,
pub fn throttling_iops_write(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsWrite<S>>where
S::ThrottlingIopsWrite: IsUnset,
Sourcepub fn maybe_throttling_iops_write(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsWrite<S>>where
S::ThrottlingIopsWrite: IsUnset,
pub fn maybe_throttling_iops_write(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsWrite<S>>where
S::ThrottlingIopsWrite: IsUnset,
Sourcepub fn throttling_iops_total_max(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsTotalMax<S>>where
S::ThrottlingIopsTotalMax: IsUnset,
pub fn throttling_iops_total_max(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsTotalMax<S>>where
S::ThrottlingIopsTotalMax: IsUnset,
Sourcepub fn maybe_throttling_iops_total_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsTotalMax<S>>where
S::ThrottlingIopsTotalMax: IsUnset,
pub fn maybe_throttling_iops_total_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsTotalMax<S>>where
S::ThrottlingIopsTotalMax: IsUnset,
Sourcepub fn throttling_iops_read_max(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsReadMax<S>>where
S::ThrottlingIopsReadMax: IsUnset,
pub fn throttling_iops_read_max(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsReadMax<S>>where
S::ThrottlingIopsReadMax: IsUnset,
Sourcepub fn maybe_throttling_iops_read_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsReadMax<S>>where
S::ThrottlingIopsReadMax: IsUnset,
pub fn maybe_throttling_iops_read_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsReadMax<S>>where
S::ThrottlingIopsReadMax: IsUnset,
Sourcepub fn throttling_iops_write_max(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsWriteMax<S>>where
S::ThrottlingIopsWriteMax: IsUnset,
pub fn throttling_iops_write_max(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsWriteMax<S>>where
S::ThrottlingIopsWriteMax: IsUnset,
Sourcepub fn maybe_throttling_iops_write_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsWriteMax<S>>where
S::ThrottlingIopsWriteMax: IsUnset,
pub fn maybe_throttling_iops_write_max(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsWriteMax<S>>where
S::ThrottlingIopsWriteMax: IsUnset,
Sourcepub fn throttling_iops_size(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsSize<S>>where
S::ThrottlingIopsSize: IsUnset,
pub fn throttling_iops_size(
self,
value: usize,
) -> FsDevLocalBuilder<SetThrottlingIopsSize<S>>where
S::ThrottlingIopsSize: IsUnset,
Sourcepub fn maybe_throttling_iops_size(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsSize<S>>where
S::ThrottlingIopsSize: IsUnset,
pub fn maybe_throttling_iops_size(
self,
value: Option<usize>,
) -> FsDevLocalBuilder<SetThrottlingIopsSize<S>>where
S::ThrottlingIopsSize: IsUnset,