Structs
- CxlFmw
- A CXL fixed memory window definition for
-machine. - CxlFmw
Builder - Use builder syntax to set the inputs and finish with
build(). - Machine
- Select the emulated machine by name. Use
-machine helpto list available machines. - Machine
Aarch64 - Machine
Aarch64 Builder - Use builder syntax to set the inputs and finish with
build(). - Machine
Builder - Use builder syntax to set the inputs and finish with
build(). - Machine
X86_ 64 - Machine
X86_ 64Builder - Use builder syntax to set the inputs and finish with
build(). - SgxEpc
- An SGX EPC section definition for
-machine sgx-epc.N.*. - SgxEpc
Builder - Use builder syntax to set the inputs and finish with
build(). - SmpCache
- Cache topology properties for
-machine smp-cache.*. - SmpCache
Builder - Use builder syntax to set the inputs and finish with
build().
Enums
- Granularity
- Supported
interleave-granularity=values forcxl-fmw. - Machine
Type - Architecture-specific machine types accepted by this crate.