Structs
- Legacy
Net - The compatibility
-netinterface retained by QEMU 11.1. - Legacy
NetBuilder - Use builder syntax to set the inputs and finish with
build(). - Network
Property - An order-preserving property used by the broad
-nicand legacy-netsyntaxes. - Nic
- QEMU’s shortcut for creating a host backend and an on-board NIC together.
- NicBuilder
- Use builder syntax to set the inputs and finish with
build().